==> style-o-matic-1.1.37.tgz: package/es/lib/CoreComponent.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/* eslint-disable */
import { Component, cloneElement } from "react";
import { uID } from "./coreUtilities.js";
import { getCorePropTypes, getCorePropDefaults } from "./propUtilities.js";
import { ROLE, getParentClass, getChildClass } from "./ROLE.js";
import EventManager from "./EventManager.js";
import UIGlobals from "./UIGlobals.js";
/* eslint-enable */
/* eslint "react/prop-types": [0] */

var CoreComponent = (_temp = _class = function (_Component) {
  _inherits(CoreComponent, _Component);

  function CoreComponent(props) {
    _classCallCheck(this, CoreComponent);

    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    var _this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this, props].concat(args)));

    _initialiseProps.call(_this);

    _this.GUID = props.uuid;
    var state = _this.state || {};
    _this.state = _extends({}, state);
    _this.node = null;
    _this.useParentNode = false;
    _this.debugging = false;
    _this.parentNode = { clientWidth: 1, clientHeight: 1 };
    return _this;
  }

  CoreComponent.prototype.componentWillMount = function componentWillMount() {
    EventManager.registerComponent(this);
    if (this.props.observe) {
      EventManager.registerObserver(this, this.props.observe);
    }
    if (this.props.dispatch) {
      EventManager.registerDispatcher(this, this.props.dispatch);
    }
    if (this.WillMount) {
      this.WillMount();
    }
  };

  CoreComponent.prototype.componentDidMount = function componentDidMount() {
    var srcState = this.state;
    var newState = srcState || {};
    if (this.props.persistentId) {
      if (srcState && !_.isEmpty(srcState)) {
        var storage = UIGlobals.readSetting(this.props.persistentId);
        if (storage) {
          var savedState = JSON.parse(storage);
          _.forIn(srcState, function (value, key) {
            if (savedState && typeof savedState[key] !== "undefined") {
              newState[key] = savedState[key];
            } else {
              newState[key] = value;
            }
          });
        }
      }
    }
    /* eslint-disable */
    this.setState(newState);
    /* eslint-enable */
  };

  CoreComponent.prototype.componentWillUnmount = function componentWillUnmount() {
    EventManager.unregisterComponent(this);
    if (this.props.observe) {
      EventManager.unregisterObserver(this, this.props.observe);
    }
    if (this.props.dispatch) {
      EventManager.unregisterDispatcher(this, this.props.dispatch);
    }
    if (this.WillUnmount) {
      this.WillUnmount();
    }
  };

  return CoreComponent;
}(Component), _class.defaultProps = getCorePropDefaults(), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.onSetRef = function (ref) {
    if (ref) {
      var needsUpdate = _this2.useParentNode && _this2.node === null;
      _this2.node = ref;
      _this2.parentNode = ref.parentNode;
      if (needsUpdate) {
        _this2.forceUpdate();
      }
    }
  };

  this.onEventDispatch = function () {
    if (_this2.props.onDispatch) {
      var _props;

      (_props = _this2.props).onDispatch.apply(_props, arguments);
    }
  };

  this.setPersistentState = function (newState) {
    if (_this2.props.persistentId) {
      UIGlobals.applySetting(_this2.props.persistentId, JSON.stringify(newState));
    }
    _this2.setState(newState);
  };

  this.setChildProps = function (role, ref, props) {
    var parentClass = getParentClass(_this2.props);
    var childClass = getChildClass(parentClass, role);
    return _extends({}, props, {
      ref: ref,
      parentclass: parentClass,
      uiclass: childClass
    });
  };

  this.chainFunction = function () {
    for (var _len2 = arguments.length, funcs = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      funcs[_key2] = arguments[_key2];
    }

    return funcs.filter(function (f) {
      return f !== null;
    }).reduce(function (acc, f) {
      if (f && typeof f !== "function") {
        throw new Error("Invalid Argument Type, must only provide functions, undefined, or null.");
      }

      if (!acc) {
        return f;
      }

      return function chainedFunction() {
        for (var _len3 = arguments.length, args = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
          args[_key3] = arguments[_key3];
        }

        acc.apply(this, args);
        f.apply(this, args);
      };
    }, null);
  };

  this.childPrefix = function (variant) {
    return getParentClass(_this2.props) + (variant ? "-" + variant : "");
  };

  this.renderChild = function (child, props) {
    if (child.props) {
      var role = child.props.uirole || ROLE.CONTENT;
      var ref = function ref(c) {
        _this2[role] = c;
      };
      if (typeof child.ref === "string") {
        throw new Error("Child components cannot set ref to string.");
      } else {
        ref = _this2.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _this2.setChildProps(role, ref, props));
    }
    return child;
  };

  this.renderOrphan = function (child, props) {
    if (child.props) {
      var role = child.props.uirole || ROLE.CONTENT;
      var ref = function ref(c) {
        _this2[role] = c;
      };
      if (typeof child.ref === "string") {
        throw new Error("Child components cannot set ref to string.");
      } else {
        ref = _this2.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        parentclass: role,
        uiclass: role
      }));
    }
    return child;
  };
}, _temp);
export { CoreComponent as default };
CoreComponent.propTypes = process.env.NODE_ENV !== "production" ? getCorePropTypes() : {};

==> style-o-matic-1.2.0.tgz: package/es/lib/CoreComponent.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof utilities
 * @namespace CoreComponent
 * @author Steven Jackson
 */
/* eslint-disable */
import React, { Component, cloneElement } from "react";
import _ from "lodash";
import { uID } from "./coreUtilities.js";
import { setCorePropTypes, setCorePropDefaults, getValidProps } from "./propUtilities.js";
import { ROLE, getParentClass, getChildClass } from "./ROLE.js";
import EventManager from "./EventManager.js";
import UIGlobals from "./UIGlobals.js";
import LoadingStateless from "../components/Loading/LoadingStateless.js";
/* eslint-enable */
/* eslint "react/prop-types": [0] */

var CoreComponent = (_temp = _class = function (_Component) {
  _inherits(CoreComponent, _Component);

  function CoreComponent(props) {
    _classCallCheck(this, CoreComponent);

    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    var _this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this, props].concat(args)));

    _initialiseProps.call(_this);

    _this.GUID = props.uuid;
    var state = _this.state || {};
    _this.state = _extends({}, state);
    _this.node = null;
    _this.useParentNode = false;
    _this.debugging = false;
    _this.parentNode = { clientWidth: 1, clientHeight: 1 };
    return _this;
  }

  CoreComponent.prototype.componentWillMount = function componentWillMount() {
    EventManager.registerComponent(this);
    if (this.props.observe) {
      EventManager.registerObserver(this, this.props.observe);
    }
    if (this.props.dispatch) {
      EventManager.registerDispatcher(this, this.props.dispatch);
    }
    if (this.WillMount) {
      this.WillMount();
    }
  };

  CoreComponent.prototype.componentDidMount = function componentDidMount() {
    var srcState = this.state;
    var newState = srcState || {};
    if (this.props.persistentId) {
      if (srcState && !_.isEmpty(srcState)) {
        var storage = UIGlobals.readSetting(this.props.persistentId);
        if (storage) {
          var savedState = JSON.parse(storage);
          _.forIn(srcState, function (value, key) {
            if (savedState && typeof savedState[key] !== "undefined") {
              newState[key] = savedState[key];
            } else {
              newState[key] = value;
            }
          });
        }
      }
    }
    /* eslint-disable */
    this.setState(newState);
    /* eslint-enable */
  };

  CoreComponent.prototype.componentWillUnmount = function componentWillUnmount() {
    EventManager.unregisterComponent(this);
    if (this.props.observe) {
      EventManager.unregisterObserver(this, this.props.observe);
    }
    if (this.props.dispatch) {
      EventManager.unregisterDispatcher(this, this.props.dispatch);
    }
    if (this.WillUnmount) {
      this.WillUnmount();
    }
  };

  CoreComponent.prototype.render = function render() {
    var _props = this.props,
        uuid = _props.uuid,
        loader = _props.loader;

    var rendered = [this.renderCore()];
    if (loader) {
      rendered.push(React.createElement(LoadingStateless, { key: "loading-" + uuid, scene: loader }));
    }
    return rendered;
  };

  return CoreComponent;
}(Component), _class.defaultProps = setCorePropDefaults(), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.onSetRef = function (ref) {
    if (ref) {
      var needsUpdate = _this2.node === null;
      _this2.node = ref;
      _this2.parentNode = ref.parentNode;
      if (needsUpdate) {
        if (_this2.setRefCallback) {
          _this2.setRefCallback(ref);
        } else if (_this2.useParentNode) {
          _this2.forceUpdate();
        }
      }
    }
  };

  this.onEventDispatch = function () {
    if (_this2.props.onDispatch) {
      var _props2;

      (_props2 = _this2.props).onDispatch.apply(_props2, arguments);
    }
  };

  this.setPersistentState = function (newState) {
    if (_this2.props.persistentId) {
      UIGlobals.applySetting(_this2.props.persistentId, JSON.stringify(newState));
    }
    _this2.setState(newState);
  };

  this.setChildProps = function (role, ref, props) {
    var parentClass = getParentClass(_this2.props);
    var childClass = getChildClass(parentClass, role);
    return _extends({}, props, {
      ref: ref,
      parentclass: parentClass,
      uiclass: childClass
    });
  };

  this.chainFunction = function () {
    for (var _len2 = arguments.length, funcs = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      funcs[_key2] = arguments[_key2];
    }

    return funcs.filter(function (f) {
      return f !== null;
    }).reduce(function (acc, f) {
      if (f && typeof f !== "function") {
        throw new Error("Invalid Argument Type, must only provide functions, undefined, or null.");
      }

      if (!acc) {
        return f;
      }

      return function chainedFunction() {
        for (var _len3 = arguments.length, args = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
          args[_key3] = arguments[_key3];
        }

        acc.apply(this, args);
        f.apply(this, args);
      };
    }, null);
  };

  this.childPrefix = function (variant) {
    return getParentClass(_this2.props) + (variant ? "-" + variant : "");
  };

  this.renderChild = function (child, props) {
    if (child.props) {
      var role = child.props.uirole || ROLE.CONTENT;
      var ref = function ref(c) {
        _this2[role] = c;
      };
      if (typeof child.ref === "string") {
        throw new Error("Child components cannot set ref to string.");
      } else {
        ref = _this2.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _this2.setChildProps(role, ref, props));
    }
    return child;
  };

  this.renderOrphan = function (child, props) {
    if (child.props) {
      var role = child.props.uirole || ROLE.CONTENT;
      var ref = function ref(c) {
        _this2[role] = c;
      };
      if (typeof child.ref === "string") {
        throw new Error("Child components cannot set ref to string.");
      } else {
        ref = _this2.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        parentclass: role,
        uiclass: role
      }));
    }
    return child;
  };

  this.renderCore = function () {
    var _getValidProps = getValidProps(_this2.props),
        ElementType = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      ElementType,
      props,
      children
    );
  };
}, _temp);
export { CoreComponent as default };
CoreComponent.propTypes = process.env.NODE_ENV !== "production" ? setCorePropTypes() : {};
